#
# Licensed Materials - Property of IBM
# Rational ClearQuest
# (C) Copyright IBM Corp. 2008, 2009.  All Rights Reserved
# US Government Users Restricted Rights
# Use, duplication or disclosure restricted by GSA ADP Schedule Contract with IBM Corp
#

import os, sys, java, string

def isunix():
    os_name = java.lang.System.getProperty('os.name')
    os_name = os_name.lower()
    print "OS: " + os_name
    return os_name.find('windows') < 0


def add_cq_envs_to_was_server():

    if not isunix():
        print "not unix skipping env set"
        return 

    print "Setting WAS CQ envs"

    clearquest = r"/opt/rational/clearquest/bin/clearquest"
    tempfile = r".cq-output-tempfile.txt"

    print "ClearQuest: " + clearquest

    command = '"%s" -dumpsh > "%s"' % (clearquest, tempfile) 

    os.system(command)

    input = open(tempfile, 'r')
    Lines = input.readlines()
    input.close()

    cqenvs = {}

    for l in Lines:
        # skip over export lines.  Don't care about them
        if l.startswith("export"): continue
        parts = l.split("=")
        value = parts[1]
        # strip off the begining "'" and the trailing "';\n"
        value = value[1:-3]
        cqenvs[ parts[0] ] = value

    os.remove(tempfile)

    serverid = AdminConfig.getid('/Server:server1/JavaProcessDef:/')
    server = AdminConfig.list('JavaProcessDef', serverid)

    config_was_env = AdminConfig.showAttribute(server, 'environment')

    config_was_env = config_was_env[1:-1]
    existing_was_envs = config_was_env.split(' ')

    # if env entries already exist then update them
    for was_env in existing_was_envs:
        if len(was_env) == 0: continue
        name = AdminConfig.showAttribute(was_env, 'name')
        if cqenvs.has_key(name):
            print "Modify: " + name
            AdminConfig.modify(was_env, [['value', cqenvs[ name ]]])
            del cqenvs[ name ]

    # add any missing envs
    for key in cqenvs.keys():
        print "Add: " + key
        value = [ ['name', key], ['value', cqenvs[key]] ]
        AdminConfig.create('Property', server, value, 'environment') 

    AdminConfig.save()

#-----------------------------------------------------------------
# Sets JVM's variable for solr.solr.home
#-----------------------------------------------------------------
def setSolrHome(interactive, solrHome):

    global AdminApp
    global AdminConfig

    solrJvmParameters = "-Dsolr.solr.home=" + solrHome
    
    server1 = AdminConfig.getid('/Server:server1/JavaProcessDef:/JavaVirtualMachine:/')
    jvm = AdminConfig.list('JavaVirtualMachine', server1)

    existingGenericJvmArguments = AdminConfig.showAttribute(jvm, 'genericJvmArguments')

    newGenericJvmArguments = solrJvmParameters

    print ""
    print "This script change 'genericJvmArguments' to set 'solr.solr.home'"
    print ""
    print "Current setting for 'genericJvmArguments' is: " + existingGenericJvmArguments

    items = string.split(existingGenericJvmArguments, " ")

    # Walk through existing items and replace 'solr.solr.home's value
    if len(items) >= 1:
        for item in items:
            keyVal = string.split(item, "=")
            if len(keyVal) == 2:
                if keyVal[0] == "-Dsolr.solr.home":
                    continue    # skip over 'solr.solr.home' since we are trying to replace it
            newGenericJvmArguments += " " + item

    # Give the user a chance to edit the raw data
    while 1:
        if interactive == "-interactive:no":
            break   # don't be interactive

        print ""
        print "New setting for 'genericJvmArguments' is: " + newGenericJvmArguments

        userResponse = raw_input("Do you want to modify it? (y/n): ")

        if userResponse == "n":
            break
        else:
            newGenericJvmArguments = raw_input("Enter new value: ")

    AdminConfig.modify(jvm, [['genericJvmArguments', newGenericJvmArguments]])

    AdminConfig.save()

    print ""
    print "'genericJvmArguments' was changed to: " + newGenericJvmArguments
    print ""
    print "The 'cqsearchprofile' MUST be restarted for this change to take effect."


#-----------------------------------------------------------------
# Main
#-----------------------------------------------------------------
if (len(sys.argv) != 2):
    print "This script will change the java system property to include 'solr.solr.home'"
    print "In doing so, it will change the value of 'genericJvmArguments' in your server.xml file"
    print ""
    print "This script requires 2 parameter: "
    print "	  1) -interactive:[yes | no]"
    print "	  2) the full path to what solr.solr.home should be set to"
    print ""
    print "e.g.:     setSolrHome -interactive:yes /CQ.Solr/SAMPL/Solr/solr"
else:
    add_cq_envs_to_was_server()
    setSolrHome(sys.argv[0], sys.argv[1])
